@@ -36,4 +36,4 @@ def download(ctx, urls, output_dir, input_file, quiet):
 
             download_urls.append(url)
 
-    files_client.download_files(ctx.obj['drs-url'], download_urls, output_dir)
+    files_client.download_files(ctx.obj['drs-url'], download_urls, output_dir, ctx.obj.get('oauth_token', None))
