@@ -7,7 +7,6 @@ from covid_cloud.client import *
 @click.pass_context
 def search(ctx):
     assert_config(ctx, 'search-url')
-    ctx.obj["search-client"] = SearchClient(ctx.obj['search-url'])
 
 
 @search.command()
@@ -17,7 +16,7 @@ def search(ctx):
 @click.option('-j', '--use-json', '--json', is_flag=True)
 @click.option('-r', '--raw', is_flag=True)
 def query(ctx, q, download, use_json, raw):
-    click.echo(search_client.query(ctx.obj['search-url'], q, download, use_json, raw))
+    click.echo(search_client.query(ctx.obj['search-url'], q, download, use_json, raw, ctx.obj.get('oauth_token', None)))
 
 
 search.add_command(tables_commands.tables)
